@@ -6,7 +6,7 @@ from cms.plugin_pool import plugin_pool
 
 class AjaxTextPlugin(TextPlugin):
     name = _(u'Text (asynchronous loading)')
-    ajax_render_template = 'plugin/ajax_text.html'
+    ajax_render_template = 'cms_ajax_text_plugin/plugin.html'
     text_enabled = True
 
     def get_ajax_body(self, instance, context):
@@ -15,9 +15,11 @@ class AjaxTextPlugin(TextPlugin):
 
     def render(self, context, instance, placeholder):
         request = context.get('request')
+        if 'updatecache' in request.GET:
+            instance.args = '?updatecache'
+        context['object'] = instance
         edit_mode = request and 'edit' in request.GET
         is_ajax = request and request.is_ajax()
-        context['object'] = instance
         if edit_mode or is_ajax:
             context = super(AjaxTextPlugin, self).render(context, instance, placeholder)
             return context
